@@ -10,12 +10,14 @@ $libdir = File.join(CONFIG["libdir"], "ruby", $version)
 $site_libdir = $:.find {|x| x =~ /site_ruby$/}
 if !$site_libdir
   $site_libdir = File.join($libdir, "site_ruby")
-elsif $site_libdir !~ Regexp.quote($version)
+elsif Regexp.compile($site_libdir) !~ Regexp.quote($version)
   $site_libdir = File.join($site_libdir, $version)
 end
 
 default_destdir = $site_libdir
 
+default_bindir = CONFIG["bindir"]
+
 def install_rb(srcdir, destdir)
   libdir = "lib"
   libdir = File.join(srcdir, libdir) if srcdir
@@ -36,7 +38,31 @@ def install_rb(srcdir, destdir)
   for f in path
     next if (/\~$/ =~ f)
     next if (/^\./ =~ File.basename(f))
-    File::install(File.join("lib", f), File.join(destdir, f), 0644, true)
+    File::install(File.join(libdir, f), File.join(destdir, f), 0644, true)
+  end
+end
+
+def install_bin(srcdir, destbindir)
+  localbindir = "bin"
+  localbindir = File.join(srcdir, localbindir) if srcdir
+  path = []
+  dir = []
+  Find.find(localbindir) do |f|
+    next unless FileTest.file?(f)
+    next if (f = f[localbindir.length+1..-1]) == nil
+    next if (/CVS$/ =~ File.dirname(f))
+    path.push f
+    #dir |= [File.dirname(f)]
+  end
+  #for f in dir
+  #  next if f == "."
+  #  next if f == "CVS"
+  #  File::makedirs(File.join(destbindir, f))
+  #end
+  for f in path
+    next if (/\~$/ =~ f)
+    next if (/^\./ =~ File.basename(f))
+    File::install(File.join(localbindir, f), File.join(destbindir, f), 0755, true)
   end
 end
 
@@ -60,14 +86,15 @@ def ARGV.req_arg
 end
 
 destdir = default_destdir
+bindir = default_bindir
 
 begin
   while switch = ARGV.switch
     case switch
     when '-d', '--destdir'
       destdir = ARGV.req_arg
-#    when '-u', '--uninstall'
-#      uninstall = true
+    when '-b', '--bindir'
+      bindir = ARGV.req_arg
     else
       raise "unknown switch #{switch.dump}"
     end
@@ -75,13 +102,10 @@ begin
 rescue
   STDERR.puts $!.to_s
   STDERR.puts File.basename($0) + 
-    " -d <destdir>"
+    " -d <destdir> -b <bindir>"
   exit 1
 end    
 
-#if( defined?(uninstall) && uninstall )
-#   uninstall_rb(nil, destdir)
-#else
-   install_rb(nil, destdir)
-#end
+install_rb(nil, destdir)
+install_bin(nil, bindir)
 
