@@ -285,12 +285,31 @@ simulation. The 3rd is not physical and may not be considered as
     Returns the direction to plot the axis, which relies on the 
     VArray#axis_draw_positive method.
 
-    RETURN VALUES
+    RETURN VALUE
     * one of the following:
       * true: axis should be drawn in the increasing order (to right/upward)
       * false: axis should be drawn in the decreasing order
       * nil: not specified
 
+---cyclic?
+    Returns whether the axis is cyclic.
+    (Relies on the VArray#axis_cyclic? method.)
+    
+    RETURN VALUE
+    * one of the following:
+      * true: cyclic
+      * false: not cyclic
+      * nil: not specified
+
+---modulo
+    Returns the modulo of a cyclic axis 
+    (Relies on the VArray#axis_modulo method.)
+    
+    RETURN VALUE
+    * one of the following:
+      * Float if the modulo is defined
+      * nil if modulo is not found
+
 =end
 
 module NumRu
@@ -737,6 +756,14 @@ module NumRu
 	@pos.axis_draw_positive
       end
 
+      def cyclic?
+	@pos.axis_cyclic?
+      end
+
+      def modulo
+	@pos.axis_modulo
+      end
+
       #########  private methods ####################################
 
       private
@@ -750,6 +777,11 @@ module NumRu
 
 	 # < define numerical integration / averaging >
 
+	 ## 2005/09/12 DEVLOPMENT MEMO by horinout
+	 ## cyclic ł傤ǂPObhL΂ modulo ɒBꍇ
+	 ## _TvZ^CvłTCNbNpd݂
+         ## 悤ɂD
+
 	 if( @bare_index )
 	    @integ_weight = NArray.int(@pos.length).fill!(1)
 	    #dist = weight.length
