@@ -3,6 +3,14 @@
 
 This manual documents the methods of NumRu::GPhys defined in gphys_fft.rb
 
+=class methods
+---GPhys::fft_ignore_missing( ignore=true )
+    Set a flag (class variable) to ignore missing values. 
+    This is for data that do not have missing 
+    but is treated as potentially having missing (often
+    by having the valid_* attributes of NetCDF.)
+
+
 =methods
 ---fft(backward=false, *dims)
     Fast Fourier Transformation (FFT) by using  
@@ -38,6 +46,7 @@ This manual documents the methods of NumRu::GPhys defined in gphys_fft.rb
       gphy.fft(nil, 0,1) # forward, for the first and second dimensions.
       gphy.fft(true, -1) # backward, for the last dimension.
 
+
 ---detrend(dim1[,dim2[,...]])
     Remove means and linear trends along dimension(s) specified.
     Algorithm: 1st order polynomial fitting.
@@ -173,6 +182,11 @@ module NumRu
   class GPhys
     @@fft_forward = -1
     @@fft_backward = 1
+    @@fft_ignore_missing = false
+
+    def self.fft_ignore_missing( ignore=true )
+      @@fft_ignore_missing = ignore 
+    end
 
     COS_TAPER_SP_FACTOR = 1.0 / 0.875  # Spectral factor for the cosine taper.
                                        # Specta should be multiplied by this.
@@ -272,14 +286,18 @@ module NumRu
 
       gfc = self.copy  # make a deep clone
       if fftw3
-	fcoef = FFTW3.fft( gfc.data.val, dir, *dims )
+	val = gfc.data.val
+	val = val.to_na if @@fft_ignore_missing and val.is_a?(NArrayMiss)
+	fcoef = FFTW3.fft( val, dir, *dims )
       else
 	# --> always FFT for all dimensions
 	if dims.length == 0
 	  raise ArgumentError,
 	    "dimension specification is available only if FFTW3 is installed"
 	end
-	fcoef = FFTW.fftw( gfc.data.val, dir )
+	val = gfc.data.val
+	val = val.to_na if @@fft_ignore_missing and val.is_a?(NArrayMiss)
+	fcoef = FFTW.fftw( val, dir )
       end
       if dir == @@fft_forward
 	if dims.length == 0
