@@ -746,4 +746,18 @@ if $0 == __FILE__
   f=NetCDF.create('tmpE4.nc')
   grid = GPhys::NetCDF_IO.write_grid(f,temp)
   p grid,grid.axis(0).pos.val
+  f.close
+
+  print "\n\n** axis conventions **\n\n"
+  x = temp.axis(0).copy.to_gphys
+  x.coord(0).set_att('topology','circular')
+  x.coord(0).set_att('modulo',[360.0])
+  p x
+  f=NetCDF.create('tmpE5.nc')
+  GPhys::NetCDF_IO.write_grid(f,x)
+  f.close
+  f=NetCDF.open('tmpE5.nc')
+  x=GPhys::NetCDF_IO.open(f,'lon')
+  p x.coord(0).axis_cyclic?
+  p x.coord(0).axis_modulo
 end
