@@ -686,7 +686,7 @@ module NumRu
             end
           end
           dlon2 = (lo2-lo1).to_f/(nlon-1)
-          dlon2.round==dlon.round || raise("Warning: dlon is not same: #{dlon2/1000} != #{dlon.to_f/1000}\n")
+          dlon2.round==dlon.round || $stderr.print("Warning: dlon is not same: #{dlon2/1000} != #{dlon.to_f/1000}\n")
           vlon = NArray.sfloat(nlon).indgen*dlon2+lo1
           if flag_scani==1
             vlon = vlon[-1..0]
@@ -1628,17 +1628,20 @@ module NumRu
             return false
           end
         end
+=begin
         if pds1.time_range!=pds2.time_range
           $stderr.printf("time range is not same: #{pds1.time_range} != #{pds2.time_range}\n")
-          return false
+          return true
+#          return false
         end
+=end
         if pds1.sub_center!=pds2.sub_center
           $stderr.printf("sub center is not same: #{pds1.sub_center} != #{pds2.sub_center}\n")
           return false
         end
         if var1.gds!=var2.gds
           $stderr.printf("gds is not same\n")
-        return false
+          return false
         end
         return true
       end
