@@ -604,6 +604,7 @@ NAMES_UNITS = {
   PARAM_GPT_DEP => nil,
   PARAM_PRESSURE_DEP => nil,
   PARAM_LAST_ENTRY => nil,
+  PARAM_LN_PRES => ["Logarithm of surface pressure", "LNSP", "", nil],
 
 
 ## NCEP Edition 2
@@ -692,7 +693,7 @@ NAMES_UNITS = {
 #227	AMIXL	m		Asymptotic mixing length scale		
 #228	PEVAP	kg/m2		Potential evaporation		
 #229	SNOHF	W/m2		Snow phase-change heat flux
-  PARAM_5WAVA =>["5-wave geopotential height anomaly", "5WAVA", "gpm"],
+  PARAM_5WAVA =>["5-wave geopotential height anomaly", "5WAVA", "gpm", nil],
 #231	MFLUX	Pa/s		Convective cloud mass flux		
 #232	DTRF	W/m2		Downward total radiation flux		
 #233	UTRF	W/m2		Upward total radiation flux		
@@ -749,7 +750,7 @@ NAMES_UNITS = {
 
 #  53 => PARAM_MNTPOT,
 
-#  60 => PARAM_POT_VOR,
+   PARAM_POT_VOR => ["Potential vorticity", "PV", "K m2/kg/s", nil],
 
 #  127 => PARAM_ATM_TIDE,
 #  128 => PARAM_BUDG_VAL
@@ -797,10 +798,10 @@ NAMES_UNITS = {
 #  199 => PARAM_VEG_FRAC,
 #  200 => PARAM_ORG_VARI,
 
-#  203 => PARAM_OZON_MIX,
+  PARAM_OZON_MIX => ["Ozone mass mixing ratio", "O3", "kg/kg", nil],
 #  204 => PARAM_PRECIP_WGT,
 #  205 => PARAM_RUNOFF,
-PARAM_OZON_TOT => ["Total column ozone", "TCO3", "Dobson", nil],
+  PARAM_OZON_TOT => ["Total column ozone", "TCO3", "Dobson", nil],
 
 #  208 => PARAM_RDN_SOL_CS_TOP,
 #  209 => PARAM_RDN_THE_CS_TOP,
@@ -1076,13 +1077,16 @@ PARAMS_ECMWF_128 = {   #inconmplte
   3 => PARAM_POT_TEMP,
   4 => PARAM_EQPT_TEMP,
   5 => PARAM_SEPT_TEMP,
+
   11 => PARAM_U_DIV_WND,
   12 => PARAM_V_DIV_WND,
   13 => PARAM_U_ROT_WND,
   14 => PARAM_V_ROT_WND,
+
   21 => PARAM_UBC_TEMP,
   22 => PARAM_UB_PRES,
   23 => PARAM_UB_DIV,
+
   26 => PARAM_LAKE_COV,
   27 => PARAM_LVEG_COV,
   28 => PARAM_HVEG_COV,
