@@ -7,6 +7,8 @@ require "numru/gphys/varray"   # for constants of VArray
 ==INDEX
 * ((<module NumRu::NetCDF_Conventions>))
 * ((<module NumRu::NetCDF_Convention_Users_Guide>))
+  * ((<module NumRu::NetCDF_Convention_Users_Guide::Attribute_Mixin>))
+  * ((<module NumRu::NetCDF_Convention_Users_Guide::VArray_Mixin>))
 * ((<module NumRu::NetCDF_Convention_Wind_Profiler>))
 
 =module NumRu::NetCDF_Conventions
@@ -58,9 +60,14 @@ The NetCDF Users Guide Convention
 
 ==Constants
 
----module VArray_Mixin
+---Attribute_Mixin
+
+See below: ((<module NumRu::NetCDF_Convention_Users_Guide::Attribute_Mixin>)).
+
+---VArray_Mixin
+
+See below: ((<module NumRu::NetCDF_Convention_Users_Guide::VArray_Mixin>)).
 
-The module to be mixed in NumRu::VArrayNetCDF.
 
 ==Module Functions
 
@@ -87,6 +94,34 @@ The module to be mixed in NumRu::VArrayNetCDF.
     Document to be written. (returns false&nil in this convention.)
     Might be reorganized in future when the gtool4 convention is supported.
 
+--------------------------------------------------
+==module NumRu::NetCDF_Convention_Users_Guide::Attribute_Mixin
+
+The module to be mixed in NumRu::AttributeNetCDF.
+
+===Instance Methods 
+
+Methods below will become sigular methods of NumRu::AttributeNetCDF.
+
+---copy(to=nil)
+    Same as (('super')) (the one overridden by this method), 
+    but edits some standard attributes if (('to')) is nil (copy onto memory)):
+    * scale_factor, add_offset: removed, since data copying includes 
+      "unpaking" by interpreting them
+    * valid_*, missing_value: unpacked if packed.
+    * _FillValue, FORTRAN_format, C_format: eliminated
+
+---------------------------------------------------
+==module NumRu::NetCDF_Convention_Users_Guide::VArray_Mixin
+
+The module to be mixed in NumRu::VArrayNetCDF.
+
+===Instance Methods
+
+Currently none, meaning is that no modification is made 
+in VArrayNetCDF.
+
+---------------------------------------------------------------------
 =module NumRu::NetCDF_Convention_Wind_Profiler
 
 The Wind Profiler convention 
@@ -166,7 +201,7 @@ module NumRu
     # NetCDF Convention of the NetCDF User's Guide
     # To be used by (not to be included in) NetCDF_IO.
 
-    module VArray_Mixin
+    module Attribute_Mixin
 
       def _unpack_missing_specification(attr)
 	# -- private method --
@@ -179,7 +214,7 @@ module NumRu
 	  raise "add_offset is not a numeric" if ao.is_a?(String)
 	  raise "scale_factor is not a numeric" if sf.is_a?(String)
 	  satyp = ( ao || sf ).typecode
-	  extyp = self.typecode
+	  extyp = @nv.typecode
 	  sf = 1 if !sf
 	  ao = 0 if !ao
 	  if (x=attr['valid_range']) && (x.typecode==extyp ||x.typecode!=satyp)
@@ -194,6 +229,7 @@ module NumRu
 	  if (x=attr['missing_value']) && (x.typecode==extyp || x.typecode!=satyp)
 	      attr['missing_value'] = x * sf + ao
 	  end
+	  attr
 	end
       end
       private :_unpack_missing_specification
@@ -210,45 +246,20 @@ module NumRu
 	attr.delete('_FillValue')
 	##attr.delete('long_name')
 
+	attr
       end
       private :_op_attr_edit
 
       def copy(to=nil)
-	result = super
-	_op_attr_edit(result.attr) if !to
-	result
+	newattr = super
+	newattr = _op_attr_edit(newattr) if !to
+	newattr
       end
 
-      VArray::Binary_operators.each{ |f|
-	eval <<-EOS, nil, __FILE__, __LINE__+1
-	  def #{f.delete(".")}(other)
-            result = super
-            _op_attr_edit(result.attr)
-            result
-          end
-        EOS
-      }
-
-      VArray::Math_funcs.each{ |f|
-	eval <<-EOS, nil, __FILE__, __LINE__+1
-	  def #{f}(*arg)
-            result = super
-            _op_attr_edit(result.attr)
-            result
-          end
-        EOS
-      }
-
-      VArray::Unary_operators.each{ |f|
-	eval <<-EOS, nil, __FILE__, __LINE__+1
-	  def #{f}
-            result = super
-            _op_attr_edit(result.attr)
-            result
-          end
-        EOS
-      }
+    end  # module Attribute_Mixin
 
+    module VArray_Mixin
+      # currently none
     end  # module VArray_Mixin
 
     ####################
@@ -294,6 +305,10 @@ module NumRu
     # Wind Profiler Convention
     # http://www.kurasc.kyoto-u.ac.jp/radar-group/wind_profiler_conventions/
 
+    module Attribute_Mixin
+      include NetCDF_Convention_Users_Guide::Attribute_Mixin
+    end    # module Attribute_Mixin
+
     module VArray_Mixin
       include NetCDF_Convention_Users_Guide::VArray_Mixin
     end    # module VArray_Mixin
