@@ -184,6 +184,7 @@ module NumRu
 	       raise "mapping #{slicer} is invalid (dim_len=#{dim_len})"
 	    end
 	    first = first
+	    step = -step if ( (last-first)*step < 0 )
 	    length = (last-first) / step + 1
 	    SubsetMapping1D.new0.initialize_regular(slicer, false, 
 						   first, length, step)
@@ -304,9 +305,19 @@ if $0 == __FILE__
    p '##',m2.slicer,m2.regular,m2.collapsed,m2.first,m2.length,m2.step,m2.index_array
    m = m.composite(m2)
    p '%%',m.slicer,m.regular,m.collapsed,m.first,m.length,m.step,m.index_array
+
+   print "########\n"
+   m =  SubsetMapping1D.new(40,{-2..1,-2})
+   p '%%',m.slicer,m.regular,m.collapsed,m.first,m.length,m.step,m.index_array
+   m2 =  SubsetMapping1D.new(10,{1..9,4})
+   print "+++ #{m.map(0)} #{m.map(1)} #{m.imap(0)} #{m.imap(1)}\n"
+   p '##',m2.slicer,m2.regular,m2.collapsed,m2.first,m2.length,m2.step,m2.index_array
+   m = m.composite(m2)
+   p '%%',m.slicer,m.regular,m.collapsed,m.first,m.length,m.step,m.index_array
+
+   print "########\n"
    m =  SubsetMapping1D.new(10,[0..9,4])
    p '##',m.slicer,m.regular,m.collapsed,m.first,m.length,m.step,m.index_array
-
    mm = SubsetMapping.new([5,6,6],[1..3, -1, 3..-1])
    p '@@@@',mm,mm.shape
    p '@@', mp=mm.map( -1, -2 ), mm.imap(*mp)
