@@ -232,10 +232,36 @@ NOMENCLATURE
     The current implementation is based on NetCDF conventions, 
     so REDEFINE IT IN SUBCLASSES if it is not appropriate.
     
-    Return values
-    * true: axis should be drawn in the increasing order (to right/upward)
-    * false: axis should be drawn in the decreasing order
-    * nil: not specified
+    RETURN VALUE
+    * one of the following:
+      * true: axis should be drawn in the increasing order (to right/upward)
+      * false: axis should be drawn in the decreasing order
+      * nil: not specified
+
+---axis_cyclic?
+    Returns whether the axis is cyclic (meaningful only if self is a
+    coordinate variable.) 
+    
+    The current implementation is based on NetCDF conventions, 
+    so REDEFINE IT IN SUBCLASSES if it is not appropriate.
+    
+    RETURN VALUE
+    * one of the following:
+      * true: cyclic
+      * false: not cyclic
+      * nil: not specified
+
+---axis_modulo
+    Returns the modulo of a cyclic axis (meaningful only if self is a
+    coordinate variable and it is cyclic.) 
+    
+    The current implementation is based on NetCDF conventions, 
+    so REDEFINE IT IN SUBCLASSES if it is not appropriate.
+    
+    RETURN VALUE
+    * one of the following:
+      * Float if the modulo is defined
+      * nil if modulo is not found
 
 ---coerce(other)
     For Numeric operators. (If you do not know it, see a manual or book of Ruby)
@@ -562,17 +588,58 @@ These methods returns a NArray (not a VArray).
       end
 
       def axis_draw_positive
+	# Default setting is taken from a widely used netcdf convention.
+	# You can override it in a sub-class or using convention specific 
+	# mixins.
 	positive = attr['positive']
 	case positive
-	when 'up'
+	when /up/i
 	  true
-	when 'down'
+	when /down/i
 	  false
 	else
 	  nil    # not defined, or if not 'up' or 'down'
 	end  
       end
 
+      def axis_cyclic?
+	# Default setting is taken from a widely used netcdf convention.
+	# You can override it in a sub-class or using convention specific 
+	# mixins.
+	topology = attr['topology']
+	case topology
+	when /circular/i
+	  true
+	when nil     # 'topology' not defined
+	  if attr['units'] == 'degrees_east'
+	    true     # special treatment a common convention for the earth
+	  else
+	    nil      # not defined --> nil
+	  end
+	else
+	  false
+	end  
+      end
+
+      def axis_modulo
+	# Default setting is taken from a widely used netcdf convention.
+	# You can override it in a sub-class or using convention specific 
+	# mixins.
+	if attval=attr['modulo']
+	  if attval.is_a?(String)
+	    attval.to_f
+	  else
+	    attval[0]
+	  end
+	else
+	  if attr['units'] == 'degrees_east'
+	    360.0     # special treatment a common convention for the earth
+	  else
+	    nil      # not defined --> nil
+	  end
+	end
+      end
+
       ### < NArray methods > ###
 
       ## ToDo: implement units handling
@@ -691,9 +758,9 @@ These methods returns a NArray (not a VArray).
             when VArray, UNumeric
 	       vl = self.val
 	       vr = other.val
-	       begin
+	       if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
 		 ary = vl#{f}(vr)
-	       rescue
+	       else
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
@@ -702,9 +769,9 @@ These methods returns a NArray (not a VArray).
 	    when Numeric, NArray, NArrayMiss, Array
 	       vl = self.val
 	       vr = other
-	       begin
+	       if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
 		 ary = vl#{f}(vr)
-	       rescue
+	       else
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
@@ -732,19 +799,23 @@ These methods returns a NArray (not a VArray).
 		 oval = other.val
 		 uni = other.units
 	       end
-               begin
-                 ary = self.val#{f}( oval )
-               rescue
-                 ary = NArrayMiss.to_nam(self.val)#{f}( oval )
+	       vl = self.val
+	       vr = oval
+               if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
+                 ary = vl#{f}(vr)
+               else
+                 ary = NArrayMiss.to_nam(vl)#{f}(vr)
                end
 	       va = VArray.new( ary, self.attr_copy, self.name )
 	       va.units = uni
 	       va
 	    when Numeric, NArray, NArrayMiss, Array
-               begin
-		 ary = self.val#{f}(other)
-               rescue
-		 ary = NArrayMiss.to_nam(self.val)#{f}(other)
+	       vl = self.val
+	       vr = other
+	       if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
+		 ary = vl#{f}(vr)
+               else
+		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       VArray.new( ary, self.attr_copy, self.name )
             else
@@ -761,18 +832,18 @@ These methods returns a NArray (not a VArray).
             when VArray, UNumeric
 	       vl = self.val
 	       vr = other.val
-	       begin
+	       if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
 		 ary = vl#{f}(vr)
-	       rescue
+	       else
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       VArray.new( ary, self.attr_copy, self.name )
 	    when Numeric, NArray, NArrayMiss, Array
 	       vl = self.val
 	       vr = other
-	       begin
+	       if !( vl.is_a?(NArray) and vr.is_a?(NArrayMiss) )
 		 ary = vl#{f}(vr)
-	       rescue
+	       else
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       VArray.new( ary, self.attr_copy, self.name )
@@ -982,4 +1053,11 @@ if $0 == __FILE__
    p vg.units,vg.val
    vkg = vg.convert_units('kg')
    p vkg.units,vkg.val
+
+   p '*axis conventions*'
+   p vx = VArray.new( NArray.int(6).indgen!, nil, 'x' )
+   vx.set_att('topology','circular')
+   vx.set_att('modulo',[360.0])
+   vx.set_att('positive','down')
+   p vx.axis_draw_positive, vx.axis_cyclic?, vx.axis_modulo
 end
